@@ -1,7 +1,8 @@
 package Data::Riak::Bucket;
 {
-  $Data::Riak::Bucket::VERSION = '0.5';
+  $Data::Riak::Bucket::VERSION = '0.6';
 }
+# ABSTRACT: A Data::Riak bucket, used for storing keys and values.
 
 use strict;
 use warnings;
@@ -17,12 +18,14 @@ use JSON::XS qw/decode_json encode_json/;
 
 with 'Data::Riak::Role::HasRiak';
 
+
 has name => (
     is => 'ro',
     isa => 'Str',
     required => 1
 );
 
+
 sub add {
     my ($self, $key, $value, $opts) = @_;
 
@@ -65,6 +68,7 @@ sub add {
     return;
 }
 
+
 sub remove {
     my ($self, $key, $opts) = @_;
 
@@ -79,6 +83,8 @@ sub remove {
     });
 }
 
+
+
 sub get {
     my ($self, $key, $opts) = @_;
 
@@ -101,6 +107,8 @@ sub get {
     })->first;
 }
 
+
+
 sub list_keys {
     my $self = shift;
 
@@ -113,6 +121,7 @@ sub list_keys {
     return decode_json( $result->value )->{'keys'};
 }
 
+
 sub count {
     my $self = shift;
     my $map_reduce = Data::Riak::MapReduce->new({
@@ -129,6 +138,7 @@ sub count {
     return $count->[0];
 }
 
+
 sub remove_all {
     my $self = shift;
     my $keys = $self->list_keys;
@@ -193,6 +203,19 @@ sub indexing {
     });
 }
 
+
+sub create_alias {
+    my ($self, $opts) = @_;
+    my $bucket = $opts->{in} || $self;
+    $bucket->add($opts->{as}, $opts->{key}, { links => [ Data::Riak::Link->new( bucket => $bucket->name, riaktag => 'perl-data-riak-alias', key => $opts->{key} )] });
+}
+
+
+sub resolve_alias {
+    my ($self, $alias) = @_;
+    return $self->linkwalk($alias, [[ 'perl-data-riak-alias', '_' ]])->first;
+}
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
@@ -204,11 +227,88 @@ no Moose;
 
 =head1 NAME
 
-Data::Riak::Bucket
+Data::Riak::Bucket - A Data::Riak bucket, used for storing keys and values.
 
 =head1 VERSION
 
-version 0.5
+version 0.6
+
+=head1 DESCRIPTION
+
+Data::Riak::Bucket is the primary interface that most people will use for Riak.
+Adding and removing keys and values, adding links, querying keys; all of those
+happen here.
+
+=head SYNOPSIS
+
+    my $bucket = Data::Riak::Bucket->new({
+        name => 'my_bucket',
+        riak => $riak
+    });
+
+    # Sets the value of "foo" to "bar", in my_bucket.
+    $bucket->add('foo', 'bar');
+
+    # Gets the Result object for "foo" in my_bucket.
+    my $foo = $bucket->get('foo');
+
+    # Returns "bar"
+    my $value = $foo->value;
+
+    $bucket->create_alias({ key => 'foo', as => 'alias_to_foo' });
+    $bucket->create_alias({ key => 'foo', as => 'alias_to_foo', in => $another_bucket });
+
+    # Returns "bar"
+    my $value = $bucket->resolve_alias('alias_to_foo');
+    my $value = $another_bucket->resolve_alias('alias_to_foo');
+
+    $bucket->add('baz, 'value of baz', { links => [$bucket->create_link( riaktag => 'buddy', key =>'foo' )] });
+    my $resultset = $bucket->linkwalk('baz', [[ 'buddy', '_' ]]);
+    my $value = $resultset->first->value;   # Will be "bar", the value of foo
+
+=head1 METHODS
+
+=head2 add ($key, $value, $opts)
+
+This will insert a key C<$key> into the bucket, with value C<$value>. The C<$opts>
+can include links, allowed content types, or queries.
+
+=head2 remove ($key, $opts)
+
+This will remove a key C<$key> from the bucket.
+
+=head2 get ($key, $opts)
+
+This will get a key C<$key> from the bucket, returning a L<Data::Riak::Result> object.
+
+=head2 list_keys
+
+List all the keys in the bucket. Warning: This is expensive, as it has to scan
+every key in the system, so don't use it unless you mean it, and know what you're
+doing.
+
+=head2 count
+
+Count all the keys in a bucket. This uses MapReduce to figure out the answer, so
+it's expensive; Riak does not keep metadata on buckets for reasons that are beyond
+the scope of this module (but are well documented, so if you are interested, read up).
+
+=head2 remove_all
+
+Remove all the keys from a bucket. This involves a list_keys call, so it will be
+slow on larger systems.
+
+=head2 create_alias ($opts)
+
+Creates an alias for a record using links. Helpful if your primary ID is a UUID or
+some other automatically generated identifier. Can cross buckets, as well.
+
+    $bucket->create_alias({ key => '123456', as => 'foo' });
+    $bucket->create_alias({ key => '123456', as => 'foo', in => $other_bucket });
+
+=head2 resolve_alias ($alias)
+
+Returns the L<Data::Riak::Result> that $alias points to.
 
 =head1 AUTHOR
 
